summaryrefslogtreecommitdiffstats
path: root/kjsembed/builtins/qfile_imp.h
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/builtins/qfile_imp.h')
-rw-r--r--kjsembed/builtins/qfile_imp.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kjsembed/builtins/qfile_imp.h b/kjsembed/builtins/qfile_imp.h
index ae88dd52..d116040e 100644
--- a/kjsembed/builtins/qfile_imp.h
+++ b/kjsembed/builtins/qfile_imp.h
@@ -17,7 +17,7 @@ class QFile;
namespace KJSEmbed {
/**
* Wrapper class for QFile methods.
*
* @author Richard Moore, rich@kde.org
*/
@@ -72,7 +72,7 @@ public:
static void addBindings( KJS::ExecState *exec, KJS::Object &object );
- static QFile *toQFile( KJS::Object &object );
+ static TQFile *toQFile( KJS::Object &object );
//
// Constructors implemented by this class.
@@ -132,7 +132,7 @@ public:
virtual KJS::Value call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args );
private:
- QFile *instance; // Temp
+ TQFile *instance; // Temp
int id;
bool cons;
};
@@ -17,7 +17,7 @@ class QFile;
namespace KJSEmbed {
/**
- * Wrapper class for QFile methods.
+ * Wrapper class for TQFile methods.
*
* @author Richard Moore, rich@kde.org